@@ -175,9 +175,6 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
     @classmethod
     def __setup__(cls):
         super(ShipmentDrop, cls).__setup__()
-        cls.__rpc__.update({
-                'button_draft': True,
-                })
         cls._transitions |= set((
                 ('draft', 'waiting'),
                 ('waiting', 'shipped'),
@@ -399,7 +396,7 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
 
         requests = []
         for sub_lines in grouped_slice([m.origin.id for s in shipments
-                    for m in s.supplier_moves]):
+                    for m in s.supplier_moves if m.origin]):
             requests += PurchaseRequest.search([
                     ('purchase_line', 'in', list(sub_lines)),
                     ])
@@ -412,6 +409,8 @@ class ShipmentDrop(Workflow, ModelSQL, ModelView):
         to_save = []
         for shipment in shipments:
             for move in shipment.supplier_moves:
+                if not move.origin:
+                    continue
                 sale_line = request2sline[pline2request[move.origin]]
                 for move in sale_line.moves:
                     if (move.state not in ('cancel', 'done')
